==> kde-workspace-4.7.2.tar.bz2: kde-workspace-4.7.2/kdm/kfrontend/sessions/kde-plasma-safe.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=XSession
Exec=${KDE4_BIN_INSTALL_DIR}/startkde --failsafe
TryExec=${KDE4_BIN_INSTALL_DIR}/startkde
Name=KDE Plasma Workspace (failsafe session)
Name[ca]=Espai de treball del Plasma del KDE (sessió a prova de fallades)
Name[cs]=Pracovní plocha plasma (bezpečná relace)
Name[da]=KDE Plasma arbejdsområde (fejlsikker session)
Name[de]=KDE-Plasma-Arbeitsplatz (Abgesicherter Modus)
Name[es]=Espacio de trabajo Plasma de KDE (sesión a prueba de fallos)
Name[et]=KDE Plasma töötsoon (turvaline seanss)
Name[eu]=KDE Plasma langunea (akatsekiko saio segurua)
Name[fi]=KDE Plasma-työtila (vikasietoinen istunto)
Name[fr]=Espace de travail de Plasma de KDE (session de secours)
Name[he]=סביבת עבודה של KDE Plasma (הפעלה בטוחה)
Name[hr]=KDE Plasma Workspace (sigurnosna sesija)
Name[hu]=KDE Plasma munkaterület (biztonságos munkamenet)
Name[ia]=Spatio de labor de plasma de KDE (session con securitate)
Name[is]=KDE Plasma-vinnurými (villuvarin seta)
Name[it]=Spazio di lavoro di KDE Plasma (sessione sicura-failsafe)
Name[kk]=KDE Plasma жұмыс орны (қауіпсіз сеанс)
Name[lt]=KDE Plasma darbastalio erdvė (saugus seansas)
Name[lv]=KDE Plasma darba vide (kļūddrošā sesija)
Name[nb]=KDE Plasma arbeidsflate (sikker økt)
Name[nds]=KDE-Arbeitrebeet Plasma (Fehlerseker-Törn)
Name[nl]=KDE Plasma-werkruimte (sessie met veilig mislukken)
Name[pa]=KDE ਪਲਾਜ਼ਮਾ ਵਰਕਸਪੇਸ (ਫੇਲ੍ਹ ਸੇਫ਼ ਸ਼ੈਸ਼ਨ)
Name[pl]=Przestrzeń robocza Plazmy (bezpieczne)
Name[pt]=Área de Trabalho Plasma do KDE (sessão de recurso)
Name[pt_BR]=Espaço de trabalho Plasma do KDE (sessão a prova de falhas)
Name[ro]=Spațiu de lucru Plasma KDE (sesiune robustă)
Name[ru]=Рабочий стол Plasma (безопасный режим)
Name[sr]=КДЕ‑ов плазма радни простор (безотказна сесија)
Name[sr@ijekavian]=КДЕ‑ов плазма радни простор (безотказна сесија)
Name[sr@ijekavianlatin]=KDE‑ov plasma radni prostor (bezotkazna sesija)
Name[sr@latin]=KDE‑ov plasma radni prostor (bezotkazna sesija)
Name[sv]=KDE Plasma arbetsyta (felsäker session)
Name[tr]=KDE Plasma Çalışma Alanı (güvenli oturum)
Name[ug]=ك د ئې(KDE) پلازما خىزمەت بوشلۇقى(بىخەتەر ئەڭگىمە)
Name[uk]=Робочий простір Плазми KDE (безпечний сеанс)
Name[x-test]=xxKDE Plasma Workspace (failsafe session)xx
Name[zh_TW]=KDE Plasma 工作空間（救援模式）
Comment=The desktop made by KDE (failsafe session)
Comment[ca]=L'escriptori creat pel KDE (sessió a prova de fallades)
Comment[cs]=Prostředí od KDE (bezpečná relace)
Comment[da]=Skrivebordet fra KDE (fejlsikker session)
Comment[de]=Die Arbeitsfläche von KDE (Abgesicherter Modus)
Comment[es]=El escritorio diseñado por KDE (sesión a prueba de fallos)
Comment[et]=KDE loodud töölaud (turvaline seanss)
Comment[eu]=KDE-k eginiko mahaigaina (akatsekiko saio segurua)
Comment[fi]=KDE:n tekemä työpöytä (vikasietoinen istunto)
Comment[fr]=Le bureau réalisé par KDE (session de secours)
Comment[he]=שולחן העבודה של KDE (הפעלה בטוחה)
Comment[hr]=Radna površina koju je napravio KDE (sigurnosna sesija)
Comment[hu]=A KDE által készített munkaasztal (biztonságos munkamenet)
Comment[ia]=Le scriptorio facite per KDE (session con securitate)
Comment[is]=KDE Skjáborð (villuvarin seta)
Comment[it]=Il desktop fatto da KDE (sessione sicura-failsafe)
Comment[kk]=KDE үстелі (қаупсіз сеанс)
Comment[lt]=Darbastalis sukurtas su KDE (saugus seansas)
Comment[lv]=KDE veidota darbvirsma (kļūddrošā sesija)
Comment[nb]=Skrivebordet som KDE laget (sikker økt)
Comment[nds]=KDE-Schriefdisch (Fehlerseker-Törn)
Comment[nl]=Het bureaublad gemaakt door KDE (sessie met veilig mislukken)
Comment[pa]=KDE ਵਲੋਂ ਬਣਾਇਆ ਡੈਸਕਟਾਪ (ਫੇਲ੍ਹਸੇਫ਼ ਸ਼ੈਸ਼ਨ)
Comment[pl]=Pulpit KDE (tryb bezpieczny)
Comment[pt]=O ambiente de trabalho feito pelo KDE (sessão de recurso)
Comment[pt_BR]=O ambiente de trabalho feito pelo KDE (sessão a prova de falhas)
Comment[ro]=Biroul creat de KDE (sesiune robustă)
Comment[ru]=Окружение рабочего стола от команды KDE (безопасный режим)
Comment[sr]=Радна површ у изведби КДЕ‑а (безотказна сесија)
Comment[sr@ijekavian]=Радна површ у изведби КДЕ‑а (безотказна сесија)
Comment[sr@ijekavianlatin]=Radna površ u izvedbi KDE‑a (bezotkazna sesija)
Comment[sr@latin]=Radna površ u izvedbi KDE‑a (bezotkazna sesija)
Comment[sv]=Skrivbordet skapat av KDE (felsäker session)
Comment[tr]=KDE masaüstü (güvenli oturum)
Comment[ug]=بۇ ئۈستەلئۈستى KDE دا ياسالغان(بىخەتەر ئەڭگىمە)
Comment[uk]=Стільниця, створена командою KDE (безпечний сеанс)
Comment[x-test]=xxThe desktop made by KDE (failsafe session)xx
Comment[zh_TW]=KDE 製作的桌面（救援模式）

==> kde-workspace-4.7.4.tar.bz2: kde-workspace-4.7.4/kdm/kfrontend/sessions/kde-plasma-safe.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=XSession
Exec=${KDE4_BIN_INSTALL_DIR}/startkde --failsafe
TryExec=${KDE4_BIN_INSTALL_DIR}/startkde
Name=KDE Plasma Workspace (failsafe session)
Name[ca]=Espai de treball del Plasma del KDE (sessió a prova de fallades)
Name[cs]=Pracovní plocha plasma (bezpečná relace)
Name[da]=KDE Plasma arbejdsområde (fejlsikker session)
Name[de]=KDE-Plasma-Arbeitsplatz (Abgesicherter Modus)
Name[es]=Espacio de trabajo Plasma de KDE (sesión a prueba de fallos)
Name[et]=KDE Plasma töötsoon (turvaline seanss)
Name[eu]=KDE Plasma langunea (akatsekiko saio segurua)
Name[fi]=KDE Plasma-työtila (vikasietoinen istunto)
Name[fr]=Espace de travail Plasma de KDE (session de secours)
Name[he]=סביבת עבודה של KDE Plasma (הפעלה בטוחה)
Name[hr]=KDE Plasma Workspace (sigurnosna sesija)
Name[hu]=KDE Plasma munkaterület (biztonságos munkamenet)
Name[ia]=Spatio de labor de plasma de KDE (session con securitate)
Name[is]=KDE Plasma-vinnurými (villuvarin seta)
Name[it]=Spazio di lavoro di KDE Plasma (sessione sicura-failsafe)
Name[kk]=KDE Plasma жұмыс орны (қауіпсіз сеанс)
Name[ko]=KDE Plasma 작업 공간 (실패 안전)
Name[lt]=KDE Plasma darbastalio erdvė (saugus seansas)
Name[lv]=KDE Plasma darba vide (kļūddrošā sesija)
Name[nb]=KDE Plasma arbeidsflate (sikker økt)
Name[nds]=KDE-Arbeitrebeet Plasma (Fehlerseker-Törn)
Name[nl]=KDE Plasma-werkruimte (sessie met veilig mislukken)
Name[pa]=KDE ਪਲਾਜ਼ਮਾ ਵਰਕਸਪੇਸ (ਫੇਲ੍ਹ ਸੇਫ਼ ਸ਼ੈਸ਼ਨ)
Name[pl]=Przestrzeń robocza Plazmy (bezpieczne)
Name[pt]=Área de Trabalho Plasma do KDE (sessão de recurso)
Name[pt_BR]=Espaço de trabalho Plasma do KDE (sessão a prova de falhas)
Name[ro]=Spațiu de lucru Plasma KDE (sesiune robustă)
Name[ru]=Рабочий стол Plasma (безопасный режим)
Name[sr]=КДЕ‑ов плазма радни простор (безотказна сесија)
Name[sr@ijekavian]=КДЕ‑ов плазма радни простор (безотказна сесија)
Name[sr@ijekavianlatin]=KDE‑ov plasma radni prostor (bezotkazna sesija)
Name[sr@latin]=KDE‑ov plasma radni prostor (bezotkazna sesija)
Name[sv]=KDE Plasma arbetsyta (felsäker session)
Name[tr]=KDE Plasma Çalışma Alanı (güvenli oturum)
Name[ug]=ك د ئې(KDE) پلازما خىزمەت بوشلۇقى(بىخەتەر ئەڭگىمە)
Name[uk]=Робочий простір Плазми KDE (безпечний сеанс)
Name[x-test]=xxKDE Plasma Workspace (failsafe session)xx
Name[zh_TW]=KDE Plasma 工作空間（救援模式）
Comment=The desktop made by KDE (failsafe session)
Comment[ca]=L'escriptori creat pel KDE (sessió a prova de fallades)
Comment[cs]=Prostředí od KDE (bezpečná relace)
Comment[da]=Skrivebordet fra KDE (fejlsikker session)
Comment[de]=Die Arbeitsfläche von KDE (Abgesicherter Modus)
Comment[es]=El escritorio diseñado por KDE (sesión a prueba de fallos)
Comment[et]=KDE loodud töölaud (turvaline seanss)
Comment[eu]=KDE-k eginiko mahaigaina (akatsekiko saio segurua)
Comment[fi]=KDE:n tekemä työpöytä (vikasietoinen istunto)
Comment[fr]=Le bureau réalisé par KDE (session de secours)
Comment[he]=שולחן העבודה של KDE (הפעלה בטוחה)
Comment[hr]=Radna površina koju je napravio KDE (sigurnosna sesija)
Comment[hu]=A KDE által készített munkaasztal (biztonságos munkamenet)
Comment[ia]=Le scriptorio facite per KDE (session con securitate)
Comment[is]=KDE Skjáborð (villuvarin seta)
Comment[it]=Il desktop fatto da KDE (sessione sicura-failsafe)
Comment[kk]=KDE үстелі (қаупсіз сеанс)
Comment[ko]=KDE에서 만든 데스크톱 (실패 안전 세션)
Comment[lt]=Darbastalis sukurtas su KDE (saugus seansas)
Comment[lv]=KDE veidota darbvirsma (kļūddrošā sesija)
Comment[nb]=Skrivebordet som KDE laget (sikker økt)
Comment[nds]=KDE-Schriefdisch (Fehlerseker-Törn)
Comment[nl]=Het bureaublad gemaakt door KDE (sessie met veilig mislukken)
Comment[pa]=KDE ਵਲੋਂ ਬਣਾਇਆ ਡੈਸਕਟਾਪ (ਫੇਲ੍ਹਸੇਫ਼ ਸ਼ੈਸ਼ਨ)
Comment[pl]=Pulpit KDE (tryb bezpieczny)
Comment[pt]=O ambiente de trabalho feito pelo KDE (sessão de recurso)
Comment[pt_BR]=O ambiente de trabalho feito pelo KDE (sessão a prova de falhas)
Comment[ro]=Biroul creat de KDE (sesiune robustă)
Comment[ru]=Окружение рабочего стола от команды KDE (безопасный режим)
Comment[sr]=Радна површ у изведби КДЕ‑а (безотказна сесија)
Comment[sr@ijekavian]=Радна површ у изведби КДЕ‑а (безотказна сесија)
Comment[sr@ijekavianlatin]=Radna površ u izvedbi KDE‑a (bezotkazna sesija)
Comment[sr@latin]=Radna površ u izvedbi KDE‑a (bezotkazna sesija)
Comment[sv]=Skrivbordet skapat av KDE (felsäker session)
Comment[tr]=KDE masaüstü (güvenli oturum)
Comment[ug]=بۇ ئۈستەلئۈستى KDE دا ياسالغان(بىخەتەر ئەڭگىمە)
Comment[uk]=Стільниця, створена командою KDE (безпечний сеанс)
Comment[x-test]=xxThe desktop made by KDE (failsafe session)xx
Comment[zh_TW]=KDE 製作的桌面（救援模式）
